@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: cu_measures.h 4168 2009-06-11 16:44:03Z pramsey $
+ * $Id: cu_measures.h 4947 2009-11-30 20:50:57Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.refractions.net
@@ -16,15 +16,18 @@
 #include "CUnit/Basic.h"
 
 #include "liblwgeom.h"
+#include "cu_tester.h"
+#include "measures.h"
+#include "lwtree.h"
 
 /***********************************************************************
 ** for Computational Geometry Suite
 */
 
-/* Set-up / clean-up functions */
-CU_pSuite register_measures_suite(void);
-int init_measures_suite(void);
-int clean_measures_suite(void);
+
 
 /* Test functions */
-void test_mindistance2d_recursive_tolerance(void);
+void test_mindistance2d_tolerance(void);
+void test_rect_tree_contains_point(void);
+void test_rect_tree_intersects_tree(void);
+
