@@ -1,17 +1,22 @@
 /**********************************************************************
- * $Id: lwgeom_geos_prepared.c 5181 2010-02-01 17:35:55Z pramsey $
+ * $Id: lwgeom_geos_prepared.c 9751 2012-05-17 13:40:30Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.refractions.net
- * Copyright 2007 Refractions Research Inc.
- * Copyright 2008 Paul Ramsey <pramsey@cleverelephant.ca>
+ *
+ * Copyright (C) 2012 Sandro Santilli <strk@keybit.net>
+ * Copyright (C) 2008 Paul Ramsey <pramsey@cleverelephant.ca>
+ * Copyright (C) 2007 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU General Public Licence. See the COPYING file.
  *
  **********************************************************************/
 
+#include <assert.h>
+
 #include "lwgeom_geos_prepared.h"
+#include "lwgeom_cache.h"
 
 /***********************************************************************
 **
@@ -275,22 +280,22 @@ PrepGeomCache*
 GetPrepGeomCache(FunctionCallInfoData *fcinfo, PG_LWGEOM *pg_geom1, PG_LWGEOM *pg_geom2)
 {
 	MemoryContext old_context;
-	PrepGeomCache* cache = fcinfo->flinfo->fn_extra;
+	GeomCache* supercache = GetGeomCache(fcinfo);
+	PrepGeomCache* cache = supercache->prep;
 	int copy_keys = 1;
 	size_t pg_geom1_size = 0;
 	size_t pg_geom2_size = 0;
 
-	/* Make sure this isn't someone else's cache object. */
-	if ( cache && cache->type != 2 ) cache = NULL;
+	assert ( ! cache || cache->type == 2 );
 
 	if (!PrepGeomHash)
 		CreatePrepGeomHash();
 
 	if ( pg_geom1 )
-		pg_geom1_size = VARSIZE(pg_geom1) + VARHDRSZ;
+		pg_geom1_size = VARSIZE(pg_geom1);
 
 	if ( pg_geom2 )
-		pg_geom2_size = VARSIZE(pg_geom2) + VARHDRSZ;
+		pg_geom2_size = VARSIZE(pg_geom2);
 
 	if ( cache == NULL)
 	{
@@ -326,7 +331,7 @@ GetPrepGeomCache(FunctionCallInfoData *fcinfo, PG_LWGEOM *pg_geom1, PG_LWGEOM *p
 		pghe.prepared_geom = 0;
 		AddPrepGeomHashEntry( pghe );
 
-		fcinfo->flinfo->fn_extra = cache;
+		supercache->prep = cache;
 
 		POSTGIS_DEBUGF(3, "GetPrepGeomCache: adding context to hash: %p", cache);
 	}
