@@ -1,6 +1,6 @@
 -- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -- 
--- $Id: topology.sql.in.c 3687 2009-02-11 18:28:53Z pramsey $
+-- $Id: topology.sql.in.c 10612 2012-10-31 21:16:08Z pramsey $
 --
 -- PostGIS - Spatial Types for PostgreSQL
 -- http://postgis.refractions.net
@@ -1686,12 +1686,12 @@ LANGUAGE 'plpgsql' _VOLATILE_STRICT;
 CREATEFUNCTION topology.CreateTopology(varchar, integer)
 RETURNS integer AS
 ' SELECT topology.CreateTopology($1, $2, -1); '
-LANGUAGE 'SQL' _VOLATILE_STRICT;
+LANGUAGE 'sql' _VOLATILE_STRICT;
 
 CREATEFUNCTION topology.CreateTopology(varchar)
 RETURNS integer AS
 ' SELECT topology.CreateTopology($1, -1, -1); '
-LANGUAGE 'SQL' _VOLATILE_STRICT;
+LANGUAGE 'sql' _VOLATILE_STRICT;
 
 --} CreateTopology
 
