@@ -1,4 +1,5 @@
-#/bin/sh
+#!/usr/bin/perl
+
 #
 # This script is aimed at restoring postgis data
 # from a dumpfile produced by pg_dump -Fc
@@ -55,6 +56,12 @@ my %types = ();
 my %opclass = ();
 my %ops = ();
 
+
+# Old aggregate functions we don't carry any more
+$aggs{"accum"} = 1;
+$aggs{"fastunion"} = 1;
+$aggs{"mem_collect"} = 1;
+
 # This are old postgis functions which might
 # still be in a dump
 my %obsoleted_function = (
@@ -115,8 +122,6 @@ my %obsoleted_function = (
 	'geometry_inter(geometry, geometry)', 1,
 	'geometry_size', 1,
 	'ggeometry_consistent', 1,
-	'create_histogram2d(box3d, integer)', 1,
-	'estimate_histogram2d(histogram2d, box)', 1,
 	'xmin(box2d)', 1,
 	'ymin(box2d)', 1,
 	'xmax(box2d)', 1,
@@ -124,7 +129,24 @@ my %obsoleted_function = (
 	'optimistic_overlap', 1,
 	'unite_finalfunc', 1,
 	'numb_sub_objs(geometry)', 1,
-	'truly_inside(geometry, geometry)', 1
+	'truly_inside(geometry, geometry)', 1,
+	'jtsnoop', 1,
+	'_st_asgml(integer, geometry, integer)', 1,
+	'text(boolean)', 1,
+	'st_text(boolean)', 1,
+	'postgis_jts_version', 1,
+	'build_histogram2d', 1,
+	'create_histogram2d', 1,
+	'estimate_histogram2d', 1,
+	'explode_histogram2d', 1,
+	'histogram2d_in', 1,
+	'histogram2d_out', 1,
+	'st_histogram2d_in', 1,
+	'st_histogram2d_out', 1,
+	'st_build_histogram2d', 1,
+	'st_create_histogram2d', 1,
+	'st_estimate_histogram2d', 1,
+	'st_explode_histogram2d', 1
 );
 
 # This are old postgis operators which might
@@ -273,14 +295,14 @@ while( my $line = <INPUT>)
 		}
 		next;
 	}
-	if ($line =~ /^create aggregate *([^ ]*) *\(/i)
+	if ( $line =~ /^create aggregate *([^ ]*) *\(/i )
 	{
 		my $name = lc($1);
 		$name =~ s/^public.//;
 		my $type = undef;
 		while( my $subline = <INPUT>)
 		{
-			if ( $subline =~ /basetype .* ([^, ]*)/ )
+			if ( $subline =~ /basetype .* ([^, ]*)/i )
 			{
 				$type = $1;
 				last;
@@ -486,6 +508,12 @@ while( my $line = <INPUT> )
 			next;
 		}
 
+		# This is an old postgis aggregate
+		if ( $name eq 'accum' )
+		{
+			print "SKIPPING old PGIS AGG $id\n" if $DEBUG;
+			next;
+		}
 		print "KEEPING AGGREGATE [$id]\n" if $DEBUG;
 		#next;
 	}
@@ -607,7 +635,7 @@ while( my $line = <INPUT> )
 	} # CAST
 
 	print OUTPUT $line;
-#	print "UNANDLED: $line"
+#	print "UNHANDLED: $line"
 }
 close( INPUT );
 close(OUTPUT);
@@ -615,9 +643,20 @@ close(OUTPUT);
 print "Producing ascii dump $dumpascii\n"; 
 open( INPUT, "pg_restore -L $dumplist $dump |") || die "Can't run pg_restore\n";
 open( OUTPUT, ">$dumpascii") || die "Can't write to $dumpascii\n";
+
+my $inCopy;
 while( my $line = <INPUT> )
 {
-	next if $line =~ /^ *--/;
+	if ( $line =~ /^COPY .+ FROM stdin;$/ )
+	{
+		$inCopy = 1;
+	}
+	elsif ( $inCopy && $line =~ /^\\\.$/ )
+	{
+		$inCopy = 0;
+	}
+
+	next if !$inCopy && $line =~ /^ *--/;
 
 	if ( $line =~ /^SET search_path/ )
 	{
@@ -685,12 +724,12 @@ print "Creating db ($dbname)\n";
 `createdb $createdb_opt $dbname`;
 die "Database creation failed\n" if ($?);
 print "Adding plpgsql\n";
-`createlang $createdb_opt plpgsql $dbname`;
+`createlang plpgsql $dbname`;
 
 #
 # Open a pipe to the SQL monitor
 #
-open( PSQL, "| psql $createdb_opt -a $dbname") || die "Can't run psql\n";
+open( PSQL, "| psql -a $dbname") || die "Can't run psql\n";
 
 #
 # Source new postgis.sql
